What if home for you?

Werever it is, you have to keep it at least somewhat clean!
But dirty won't stop comming.

In this "join equal things so they vanish" variant,
you have to actually _swipe_ things up with a broom.
Hold space to use your broom, arrow keys to just
move around. When like-dirty is together, it will
go away!
